from datetime import datetime
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import Column, Integer, String, DateTime

Base = declarative_base()


class Agent(Base):
    """
    Represents an agent that has connected to the server.

    Attributes:
        id (int): A unique identifier for the agent.
        platform (str): The platform the agent is running on.
        processor (str): The processor the agent is running on.
        memory (int): The amount of memory the agent has.
        disk (int): The amount of disk space the agent has.
        first_seen (datetime): The first time the agent was seen by the server.
        last_seen (datetime): The last time the agent was seen by the server.
    """
    __tablename__ = "agents"

    id = Column(Integer, primary_key=True)
    platform = Column(String)
    processor = Column(String)
    memory = Column(Integer)
    disk = Column(Integer)
    first_seen = Column(DateTime, default=datetime.utcnow)
    last_seen = Column(DateTime, default=datetime.utcnow)

    def __repr__(self):
        return f"Agent(id={self.id}, platform={self.platform}"
