import yaml


def load_yaml_config(file_path):
    """
    Loads a YAML configuration file.

    This function loads a YAML configuration file and returns the
    configuration data as a dictionary. If the file does not exist,
    or there is an error loading the file, the function will return
    a default configuration.

    Args:
        file_path (str): The path to the YAML configuration file.

    Returns:
        dict: A dictionary containing the configuration data.
    """
    try:
        with open(file_path, "r", encoding="utf-8") as f:
            config = yaml.safe_load(f)
    except Exception:
        # TODO: Log error
        config = {
            "host": "0.0.0.0",
            "port": 9999
        }

    return config
